[![DOI](https://zenodo.org/badge/553182204.svg)](https://zenodo.org/badge/latestdoi/553182204)

# bayes-toolbox  

`bayes-toolbox` (aka, Bayesian Statistics Toolbox [BST]) is a Python package for running sophisticated Bayesian analyses in a simple, straight forward manner. 


## Documentation

The documentation for `bayes-toolbox` is hosted [here](https://hyosubkim.github.io/bayes-toolbox/).


## Installation 

See the [installation instructions](https://hyosubkim.github.io/bayes-toolbox/getting-started/) in the [documentation](https://hyosubkim.github.io/bayes-toolbox) for detailed instructions on how to install `bayes-toolbox`. 


## Citing bayes-toolbox

If you use `bayes-toolbox` in your work, please cite using one of the following:

***APA format:***
- Kim, H. E. (2023). bayes-toolbox (Version 0.0.1) [Computer software]. https://doi.org/10.5281/zenodo.7339667

***BibTeX format:***
```
@software{Kim_bayes-toolbox_2023,
author = {Kim, Hyosub E.},
doi = {10.5281/zenodo.7339667},
month = apr,
title = {{bayes-toolbox}},
url = {https://github.com/hyosubkim/bayes-toolbox},
version = {0.0.1},
year = {2023}
}
```

## License

This work is distributed for free under a [MIT license](https://github.com/hyosubkim/bayes-toolbox/blob/main/LICENSE). 

## Acknowledgments

Thank you to the following people for generously sharing their work and knowledge:
- [John Kruschke](https://jkkweb.sitehost.iu.edu/)
- [Richard McElreath](https://xcelab.net/rm/)
- [Jordi Warmenhoven](https://github.com/JWarmenhoven)
- [PyMC developers](https://github.com/pymc-devs/pymc)
- [ArviZ developers](https://www.arviz.org/en/latest/our_team.html)


## Contributors

See the [CONTRIBUTORS.md](https://github.com/hyosubkim/bayes-toolbox/blob/main/CONTRIBUTORS.md) file for a regularly updated list of contributors. 

